@@ -31,7 +31,7 @@ gitbook = function(
   gb_config = config
   html_document2 = function(..., extra_dependencies = list()) {
     rmarkdown::html_document(
-      ..., extra_dependencies = c(extra_dependencies, gitbook_dependency(table_css, gb_config))
+      ..., extra_dependencies = c(gitbook_dependency(table_css, gb_config), extra_dependencies)
     )
   }
   if (identical(template, 'default')) {
@@ -91,13 +91,18 @@ gitbook_dependency = function(table_css, config = list()) {
   assets = bookdown_file('resources', 'gitbook')
   owd = setwd(assets); on.exit(setwd(owd), add = TRUE)
   app = if (file.exists('js/app.min.js')) 'app.min.js' else 'app.js'
-  # TODO: use fuse by default in the future
-  lunr = !identical(config$search$engine, 'fuse')
   # TODO: download and a local copy of fuse.js?
-  fuse = if (!lunr) htmltools::htmlDependency(
+  fuse = htmltools::htmlDependency(
     'fuse', '6.4.6', c(href = 'https://cdn.jsdelivr.net/npm/fuse.js@6.4.6'),
     script = 'dist/fuse.min.js'
   )
+  if (is.logical(config$search)) {
+    lunr = FALSE
+    if (!config$search) fuse = NULL
+  } else {
+    # use fuse as the search engine by default
+    lunr = identical(config$search$engine, 'lunr')
+  }
   list(jquery_dependency(), fuse, htmltools::htmlDependency(
     'gitbook', '2.6.7', src = assets,
     stylesheet = file.path('css', c(
@@ -251,9 +256,11 @@ gitbook_config = function(config = list()) {
     view = list(link = NULL, text = NULL),
     download = NULL,
     # toolbar = list(position = 'static'),
-    search = list(engine = 'lunr', options = NULL),
+    search = list(engine = 'fuse', options = NULL),
     toc = list(collapse = 'subsection')
   )
+  if (isTRUE(config$search)) config$search = NULL
+  if (xfun::isFALSE(config$search)) default$search = FALSE
   config = utils::modifyList(default, config, keep.null = TRUE)
   # remove these TOC config items since we don't need them in JavaScript
   config$toc$before = NULL; config$toc$after = NULL
